@@ -11,6 +11,46 @@ from python_hosts.hosts import Hosts, HostsEntry
 from python_hosts import exception
 
 
+def test_merge_names(tmpdir):
+    """
+    Test replacement of an ipv4 entry where just the address differs
+    """
+    hosts_file = tmpdir.mkdir("etc").join("hosts")
+    hosts_file.write("82.132.132.132\texample.com\texample\n")
+    hosts_entries = Hosts(path=hosts_file.strpath)
+    new_entry = HostsEntry(entry_type='ipv4', address='82.132.132.132', names=['another.example'])
+    hosts_entries.add(entries=[new_entry], merge_names=True)
+    assert hosts_entries.count() == 1
+    print(hosts_entries)
+    assert len(hosts_entries.entries[0].names) == 3
+    assert 'example.com' in hosts_entries.entries[0].names
+    assert 'example' in hosts_entries.entries[0].names
+    assert 'another.example' in hosts_entries.entries[0].names
+
+
+def test_add_comments(tmpdir):
+    """
+    Test adding a comment
+    """
+    entries = '127.0.0.1 example.com example2.com\n#existing comment'
+    hosts_path = tmpdir.mkdir("etc").join("hosts")
+    hosts_path.write(entries)
+    hosts_entries = Hosts(path=hosts_path.strpath)
+    assert hosts_entries.count() == 2  # 1 address and 1 comment
+    new_entry_1 = HostsEntry(entry_type='comment', comment='# an example comment')
+    new_entry_2 = HostsEntry(entry_type='comment', comment='another example comment')
+    hosts_entries.add(entries=[new_entry_1, new_entry_2], force=True)
+    assert hosts_entries.count() == 4  # 1 address and 3 comments
+    assert not hosts_entries.exists(address='3.4.5.6')
+    assert hosts_entries.exists(comment='# an example comment')
+    assert hosts_entries.exists(comment='# another example comment')
+    assert hosts_entries.exists(names=['example.com'])
+    # check the entries can be written and then read correctly
+    hosts_entries.write()
+    hosts_entries_2 = Hosts(path=hosts_path.strpath)
+    assert hosts_entries_2.count() == 4  # 1 address and 3 comments
+
+
 def test_remove_all_matching_with_loopback_address_and_multiple_names(tmpdir):
     """
     Test that a forced addition of an adblock entry with multiple names first removes 'all' matching names
